==> bibledit-0.7.tar.gz: bibledit-0.7/src/book.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_BOOK_H
#define INCLUDED_BOOK_H

#include "libraries.h"
#include "ustring.h"


class Book
{
public:
  Book (const string & path, bool split_lines, bool check_unicode);
  ~Book ();
  unsigned int number_of_chapters;
  unsigned int number_of_verses (unsigned int chapternumber);
  vector <ustring> cleaned_lines;
  void get_chapter (unsigned int chapternumber, vector <ustring>& lines);
  void set_chapter (vector <ustring> &lines);
  bool save ();
  vector <string> get_backups ();
  string get_backup_directory ();
  unsigned int get_previously_presented_chapter ();
  unsigned int get_id_index ();
private:
  void split_clean_lines (const ustring & text, vector <ustring> &lines, bool splitlines = false);
  string mypath;
  unsigned int previously_presented_chapter;
  void get_chapter_boundaries (unsigned int chapter_number, unsigned int &begin, unsigned int &end);
  string backup_directory;
  void load_execute (bool gui, const string & path, bool split_lines);
};


#endif

==> bibledit-0.9.tar.gz: bibledit-0.9/src/book.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_BOOK_H
#define INCLUDED_BOOK_H

#include "libraries.h"
#include "ustring.h"
#include "usfm.h"


class Book
{
public:
  Book (const string & path, bool split_lines, bool check_unicode, Usfm * usfm);
  ~Book ();
  unsigned int number_of_chapters;
  unsigned int number_of_verses (unsigned int chapternumber);
  vector <ustring> cleaned_lines;
  void get_chapter (unsigned int chapternumber, vector <ustring>& lines);
  void set_chapter (vector <ustring> &lines);
  bool save ();
  vector <string> get_backups ();
  string get_backup_directory ();
  unsigned int get_previously_presented_chapter ();
  unsigned int get_id_index ();
private:
  void split_clean_lines (const ustring & text, vector <ustring> &lines, bool splitlines = false);
  string mypath;
  unsigned int previously_presented_chapter;
  void get_chapter_boundaries (unsigned int chapter_number, unsigned int &begin, unsigned int &end);
  string backup_directory;
  void load_execute (bool gui, const string & path, bool split_lines);
  Usfm * myusfm;
};


#endif
